==> zego_uikit-1.7.5.tar.gz: lib/src/plugins/invitation/components/start_invitation_button.dart <==
// Flutter imports:
import 'package:flutter/material.dart';

// Project imports:
import 'package:zego_uikit/zego_uikit.dart';

class ZegoStartInvitationButton extends StatefulWidget {
  final int invitationType;
  final List<String> invitees;
  final String data;
  final int timeoutSeconds;

  final String? text;
  final TextStyle? textStyle;
  final ButtonIcon? icon;

  final Size? iconSize;
  final Size? buttonSize;
  final double? iconTextSpacing;
  final bool verticalLayout;

  /// start invitation if return true
  /// false will do nothing
  final bool Function()? onWillPressed;

  ///  You can do what you want after pressed.
  final void Function(String code, String message, List<String>)? onPressed;

  final Color? clickableTextColor;
  final Color? unclickableTextColor;
  final Color? clickableBackgroundColor;
  final Color? unclickableBackgroundColor;

  const ZegoStartInvitationButton({
    Key? key,
    required this.invitationType,
    required this.invitees,
    required this.data,
    this.timeoutSeconds = 60,
    this.text,
    this.textStyle,
    this.icon,
    this.iconSize,
    this.iconTextSpacing,
    this.verticalLayout = true,
    this.buttonSize,
    this.onWillPressed,
    this.onPressed,
    this.clickableTextColor = Colors.black,
    this.unclickableTextColor = Colors.black,
    this.clickableBackgroundColor = Colors.transparent,
    this.unclickableBackgroundColor = Colors.transparent,
  }) : super(key: key);

  @override
  State<ZegoStartInvitationButton> createState() =>
      _ZegoStartInvitationButtonState();
}

class _ZegoStartInvitationButtonState extends State<ZegoStartInvitationButton> {
  @override
  Widget build(BuildContext context) {
    return ZegoTextIconButton(
      onPressed: widget.invitees.isEmpty ? null : onPressed,
      text: widget.text,
      textStyle: widget.textStyle,
      icon: widget.icon,
      iconTextSpacing: widget.iconTextSpacing,
      iconSize: widget.iconSize,
      buttonRadius: widget.buttonSize?.width ?? 0 / 2,
      buttonSize: widget.buttonSize,
      verticalLayout: widget.verticalLayout,
      clickableTextColor: widget.clickableTextColor,
      unclickableTextColor: widget.unclickableTextColor,
      clickableBackgroundColor: widget.clickableBackgroundColor,
      unclickableBackgroundColor: widget.unclickableBackgroundColor,
    );
  }

  void onPressed() async {
    var canSendInvitation = widget.onWillPressed?.call() ?? true;
    if (!canSendInvitation) {
      return;
    }

    var result = await ZegoUIKit().getSignalingPlugin().sendInvitation(
          ZegoUIKit().getLocalUser().name,
          widget.invitees,
          widget.timeoutSeconds,
          widget.invitationType,
          widget.data,
        );

    if (widget.onPressed != null) {
      widget.onPressed!(
          result.code, result.message, result.result as List<String>);
    }
  }
}

==> zego_uikit-1.7.7.tar.gz: lib/src/plugins/invitation/components/start_invitation_button.dart <==
// Flutter imports:
import 'package:flutter/material.dart';

// Project imports:
import 'package:zego_uikit/zego_uikit.dart';

class ZegoStartInvitationButton extends StatefulWidget {
  final int invitationType;
  final List<String> invitees;
  final String data;
  final int timeoutSeconds;

  final ZegoSignalingPluginNotificationConfig? notificationConfig;

  final String? text;
  final TextStyle? textStyle;
  final ButtonIcon? icon;

  final Size? iconSize;
  final Size? buttonSize;
  final double? iconTextSpacing;
  final bool verticalLayout;

  /// start invitation if return true
  /// false will do nothing
  final bool Function()? onWillPressed;

  ///  You can do what you want after pressed.
  final void Function(String code, String message, List<String>)? onPressed;

  final Color? clickableTextColor;
  final Color? unclickableTextColor;
  final Color? clickableBackgroundColor;
  final Color? unclickableBackgroundColor;

  const ZegoStartInvitationButton({
    Key? key,
    required this.invitationType,
    required this.invitees,
    required this.data,
    this.notificationConfig,
    this.timeoutSeconds = 60,
    this.text,
    this.textStyle,
    this.icon,
    this.iconSize,
    this.iconTextSpacing,
    this.verticalLayout = true,
    this.buttonSize,
    this.onWillPressed,
    this.onPressed,
    this.clickableTextColor = Colors.black,
    this.unclickableTextColor = Colors.black,
    this.clickableBackgroundColor = Colors.transparent,
    this.unclickableBackgroundColor = Colors.transparent,
  }) : super(key: key);

  @override
  State<ZegoStartInvitationButton> createState() =>
      _ZegoStartInvitationButtonState();
}

class _ZegoStartInvitationButtonState extends State<ZegoStartInvitationButton> {
  @override
  Widget build(BuildContext context) {
    return ZegoTextIconButton(
      onPressed: widget.invitees.isEmpty ? null : onPressed,
      text: widget.text,
      textStyle: widget.textStyle,
      icon: widget.icon,
      iconTextSpacing: widget.iconTextSpacing,
      iconSize: widget.iconSize,
      buttonRadius: widget.buttonSize?.width ?? 0 / 2,
      buttonSize: widget.buttonSize,
      verticalLayout: widget.verticalLayout,
      clickableTextColor: widget.clickableTextColor,
      unclickableTextColor: widget.unclickableTextColor,
      clickableBackgroundColor: widget.clickableBackgroundColor,
      unclickableBackgroundColor: widget.unclickableBackgroundColor,
    );
  }

  void onPressed() async {
    var canSendInvitation = widget.onWillPressed?.call() ?? true;
    if (!canSendInvitation) {
      return;
    }

    await ZegoUIKit()
        .getSignalingPlugin()
        .sendInvitation(
          ZegoUIKit().getLocalUser().name,
          widget.invitees,
          widget.timeoutSeconds,
          widget.invitationType,
          widget.data,
          notificationConfig: widget.notificationConfig,
        )
        .then((result) {
      widget.onPressed
          ?.call(result.code, result.message, result.result as List<String>);
    });
  }
}
